pub struct FfiConnection { /* private fields */ }Expand description
FFI-compatible ADBC Connection wrapper.
Represents an active connection to an Exasol database. The connection is lazily established on first use (when creating a statement or performing a transaction operation).